@@ -7,6 +7,7 @@ from django.core.management import call_command
 
 from models import options
 
+
 @staff_member_required
 def synchro(request):
     if 'synchro' in request.POST:
@@ -15,7 +16,8 @@ def synchro(request):
             call_command('synchronize', stdout=so)
             messages.add_message(request, messages.INFO, so.getvalue())
         except Exception as e:
-            messages.add_message(request, messages.ERROR, 'An error occured: %s (%s)' % (str(e), e.__class__.__name__))
+            msg = 'An error occured: %s (%s)' % (str(e), e.__class__.__name__)
+            messages.add_message(request, messages.ERROR, msg)
         finally:
             so.close()
     return TemplateResponse(request, 'synchro.html', {'last': options.last_check})
